#    =====================================================================
#    =    Copyright (C) 1988 by Racal-Milgo.  All Rights Reserved.       =
#    =       Confidential, unpublished property of Racal-Milgo.          =
#    =   Rights reserved under the Copyright laws of the United States.  =
#    =====================================================================
#
#+=============================================================================
#
# Name:  	CHIP:MAKEFILE.MAK
# Ident: 	Version V01.00 (Non-SCCS)
# Type:  	Makefile
# Language:	Polytron MAKE
# Index: 	Make Chip Utility Modules
#
#
# Function:
#
#	This makefile can be used to make the GM 1982 ECM utility modules.
#	It will compile C source code to form object files and/or link object 
#	files to form ".EXE" files.
#
#
# Synopsis:
#
#	Set your current default directory to the area containing this makefile 
#	then type:
#
#	MAKE  [object] [-c]
#
#	object -	(Optional) Specifies the target object to be built.
#			You may specify one of the following:
#
#			xxx.obj -	Makes an object file from source.
#
#			timing.exe -	Makes the executable timing table
#					graph program.
#
#			fuel_r.exe -	Makes the executable fuel table
#					by RPM graph program.
#
#			fuel_m.exe -	Makes the executable fuel table
#					by MAP graph program.
#
#			txthex.exe -	Makes the executable text to hex
#					conversion program.
#
#			sparkhex.exe -	Makes the executable text to hex
#					conversion program.
#
#	-c -		(Optional) Specifies that MAKE is to create a batch
#			file by the name of MAKEFILE.BAT which will contain
#			all commands necessary to perform the requested 
#			operation.
#
#	Note:  If all arguments are omitted (i.e. the command is MAKE all by
#	itself), a MAKEFILE.BAT will be created which will perform a make of
#	all executables as though the following command were typed:
#
#		make timing.exe fuel_r.exe fuel_m.exe txthex.exe sparkhex.exe -c
#
#
# Additional Information:
#
#	This makefile can be used three ways:
#
#	1.	Interactively.  Simply type "MAKE object" and the commands will
#		be executed immediately.  Command echoes and error message 
#		output will be displayed on the PC screen as the commands are
#		executed.
#
#	2.	Attended batch.  Typing MAKE object -c will create a batch 
#		file called MAKEFILE.BAT which can then be executed simply by
#		typing MAKEFILE.  Command echoes and error message output are
#		displayed on the PC screen as the commands are executed.  This
#		technique is sometimes useful if the compiler runs out of 
#		memory when MAKE is run interactively as in 1 above.
#
#	3.	Unattended batch.  Using the same MAKEFILE.BAT as in 2 above,
#		RSE MAKEFILE >MAKE.OUT will create a log of the commands and
#		errors/warnings in MAKE.OUT.  Only a single message will
#		be sent to the PC screen as each compilation/link takes place.
#
#
#	Several output files will be generated which contain status information
#	about the operations performed:
#
#	MAKE.ERR -	This file will contain information describing failures
#			to make the requested object, if any.  If there are no
#			failures, no information will be written to MAKE.ERR.
#			All failure status messages in MAKE.ERR will be prefixed
#			with the word "ERROR:".
#
#	C.ERR -		This file will contain redirected output from the
#			C compilations.  It can be displayed to determine
#			the names of all modules compiled, and will list
#			any compilation warnings or errors.  C.ERR is
#			deleted as a first step in MAKEFILE.BAT if you
#			type MAKE, MAKE prod, MAKE dos, or MAKE nos.
#
#	L.ERR -		This file will contain redirected output from the
#			LINK operation.  It can be displayed to determine
#			the names of the object modules, and will list any
#			link warnings or errors.  L.ERR is deleted as a first
#			step in MAKEFILE.BAT if you type MAKE, MAKE prod,
#			MAKE dos, or MAKE nos.
#
#	Note:  All of the above error log files are deleted as a first step in 
#	MAKEFILE.BAT if you type "MAKE" or "MAKE all"
#
#
# Examples:
#
#	To build all executables, enter:
#
#		del *.obj (if not sure how objects were last compiled)
#   		make
#   		makefile
#
#
# Maintenance Information:
#
#	Notes:
#	------
#
#
# 	Modification History:
#	---------------------
#
#	September 20, 1989	Noel Carboni
#
#	Initial conception, taken from NCPI:MAKEFILE.MAK.
#
#
#  	January 3, 1990		Noel Carboni
#
#	Added fuel_r and fuel_m.
#
#
#  	January 23, 1990	Noel Carboni
#
#	Added txthex conversion program.
#
#
#  	October 8, 1990		Noel Carboni
#
#	Added sparkhex conversion program.
#
#-=============================================================================
#
#==============================================================================
#
#  Macro definitions.
#
#==============================================================================

# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  Name of the area we are in, as used in error messages.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

AREANAME =CHIP


# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  Compiler and linker options.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

COPTS   = -c -AS -W3 -Zl -Zp1 -X -IM:

LOPTS   = /NOE /NOI /MAP


# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  Libraries.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

CMN_LIBS     = D:\C600\LIB\slibce.lib 


# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  Header files.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

CMN_HDRS     = D:\C600\INCLUDE\stdio.h D:\C600\INCLUDE\stdlib.h


#
#==============================================================================
#
#  Special objects which in turn cause a recursive make of other objects.
#
#==============================================================================

# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  "MAKE all" or simply "MAKE" creates MAKEFILE.BAT to build all software
#   from source.  This object definition must be first.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

all:
    @if exist make.tmp del make.tmp
    @echo make $(MFLAGS) timing.exe fuel_r.exe fuel_m.exe txthex.exe sparkhex.exe -c
    @make $(MFLAGS) timing.exe fuel_r.exe fuel_m.exe txthex.exe sparkhex.exe -c make.tmp
    @echo @echo off >makefile.bat
    @showtime echo MAKEFILE.BAT created on %s. >>makefile.bat
    @echo if exist make.err del make.err >>makefile.bat
    @echo if exist c.err del c.err >>makefile.bat
    @echo if exist l.err del l.err >>makefile.bat
    @if exist make.tmp type make.tmp >>makefile.bat
    @if not exist make.tmp echo $(AREANAME) is up to date, no action required. >con:



#
#==============================================================================
#
#  Generalized rules.
#
#==============================================================================

# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  The following compiles a C source file into an object file.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

.c.obj:
    @echo off
    @echo ------------------------------------------------------------------------------
    @if exist $*.obj del $*.obj
    @echo Compiling $(AREANAME):$<. >con:
    @echo cl $(COPTS) $(CFLAGS) $<
    @cl $(COPTS) $(CFLAGS) $< >make.tmp
    @if errorlevel 1 echo ERROR:  $(AREANAME):$< failed to compile. >>make.err
    @type make.tmp
    @type make.tmp >>c.err


#
#==============================================================================
#
#  Dependencies and specific rules.
#
#==============================================================================

# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  Objects.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

timing.obj:  $(CMN_HDRS) D:\C600\INCLUDE\graph.h D:\C600\INCLUDE\errno.h	      \
    	     D:\C600\INCLUDE\string.h

fuel_r.obj: $(CMN_HDRS) D:\C600\INCLUDE\graph.h D:\C600\INCLUDE\errno.h      \
    	     D:\C600\INCLUDE\string.h

fuel_m.obj: $(CMN_HDRS) D:\C600\INCLUDE\graph.h D:\C600\INCLUDE\errno.h      \
    	     D:\C600\INCLUDE\string.h

txthex.obj: $(CMN_HDRS) D:\C600\INCLUDE\errno.h D:\C600\INCLUDE\string.h

sparkhex.obj: $(CMN_HDRS) D:\C600\INCLUDE\errno.h D:\C600\INCLUDE\string.h


# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  The following links timing.exe from objects.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

timing.exe: timing.obj 
    @if exist make.tmp del make.tmp
    @echo off
    @echo ------------------------------------------------------------------------------
    @if exist timing.exe del timing.exe
    @if exist timing.map del timing.map
    @echo timing.obj  >  timing.lnk
    @echo timing.exe  >> timing.lnk
    @echo timing.map  >> timing.lnk
    @echo $(CMN_LIBS) >> timing.lnk
    @echo Linking $(AREANAME):timing objects. >con:
    @echo link $(LOPTS) $(LFLAGS) @timing.lnk;
    @link $(LOPTS) $(LFLAGS) @timing.lnk; >l.err
    @if errorlevel 1 echo ERROR:  $(AREANAME):timing.exe link failed. >>make.err
    @type l.err


# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  The following links fuel_r.exe from objects.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

fuel_r.exe: fuel_r.obj 
    @if exist make.tmp del make.tmp
    @echo off
    @echo ------------------------------------------------------------------------------
    @if exist fuel_r.exe del fuel_r.exe
    @if exist fuel_r.map del fuel_r.map
    @echo fuel_r.obj  >  fuel_r.lnk
    @echo fuel_r.exe  >> fuel_r.lnk
    @echo fuel_r.map  >> fuel_r.lnk
    @echo $(CMN_LIBS) >> fuel_r.lnk
    @echo Linking $(AREANAME):fuel_r objects. >con:
    @echo link $(LOPTS) $(LFLAGS) @fuel_r.lnk;
    @link $(LOPTS) $(LFLAGS) @fuel_r.lnk; >l.err
    @if errorlevel 1 echo ERROR:  $(AREANAME):fuel_r.exe link failed. >>make.err
    @type l.err


# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  The following links fuel_m.exe from objects.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

fuel_m.exe: fuel_m.obj 
    @if exist make.tmp del make.tmp
    @echo off
    @echo ------------------------------------------------------------------------------
    @if exist fuel_m.exe del fuel_m.exe
    @if exist fuel_m.map del fuel_m.map
    @echo fuel_m.obj  >  fuel_m.lnk
    @echo fuel_m.exe  >> fuel_m.lnk
    @echo fuel_m.map  >> fuel_m.lnk
    @echo $(CMN_LIBS) >> fuel_m.lnk
    @echo Linking $(AREANAME):fuel_m objects. >con:
    @echo link $(LOPTS) $(LFLAGS) @fuel_m.lnk;
    @link $(LOPTS) $(LFLAGS) @fuel_m.lnk; >l.err
    @if errorlevel 1 echo ERROR:  $(AREANAME):fuel_m.exe link failed. >>make.err
    @type l.err


# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  The following links txthex.exe from objects.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

txthex.exe: txthex.obj 
    @if exist make.tmp del make.tmp
    @echo off
    @echo ------------------------------------------------------------------------------
    @if exist txthex.exe del txthex.exe
    @if exist txthex.map del txthex.map
    @echo txthex.obj  >  txthex.lnk
    @echo txthex.exe  >> txthex.lnk
    @echo txthex.map  >> txthex.lnk
    @echo $(CMN_LIBS) >> txthex.lnk
    @echo Linking $(AREANAME):txthex objects. >con:
    @echo link $(LOPTS) $(LFLAGS) @txthex.lnk;
    @link $(LOPTS) $(LFLAGS) @txthex.lnk; >l.err
    @if errorlevel 1 echo ERROR:  $(AREANAME):txthex.exe link failed. >>make.err
    @type l.err

# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =
#
#  The following links sparkhex.exe from objects.
#
# = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = =

sparkhex.exe: sparkhex.obj 
    @if exist make.tmp del make.tmp
    @echo off
    @echo ------------------------------------------------------------------------------
    @if exist sparkhex.exe del sparkhex.exe
    @if exist sparkhex.map del sparkhex.map
    @echo sparkhex.obj  >  sparkhex.lnk
    @echo sparkhex.exe  >> sparkhex.lnk
    @echo sparkhex.map  >> sparkhex.lnk
    @echo $(CMN_LIBS) >> sparkhex.lnk
    @echo Linking $(AREANAME):sparkhex objects. >con:
    @echo link $(LOPTS) $(LFLAGS) @sparkhex.lnk;
    @link $(LOPTS) $(LFLAGS) @sparkhex.lnk; >l.err
    @if errorlevel 1 echo ERROR:  $(AREANAME):sparkhex.exe link failed. >>make.err
    @type l.err


#==============================================================================
